@@ -39,6 +39,16 @@ var keysOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- dog\n- cat\n",
 		},
 	},
+	{
+		description: "Map keys with splat",
+		skipDoc:     true,
+		document:    `{dog: woof, cat: meow}`,
+		expression:  `keys[]`,
+		expected: []string{
+			"D0, P[dog], (!!str)::dog\n",
+			"D0, P[cat], (!!str)::cat\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `{}`,
