@@ -11,6 +11,16 @@ var sortByOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[{a: apple}, {a: banana}, {a: cat}]\n",
 		},
 	},
+	{
+		description: "Sort by string field",
+		skipDoc:     true,
+		document:    "[{a: banana},{a: apple}]",
+		expression:  `sort_by(.a)[]`,
+		expected: []string{
+			"D0, P[1], (!!map)::{a: apple}\n",
+			"D0, P[0], (!!map)::{a: banana}\n",
+		},
+	},
 	{
 		description: "Sort by multiple fields",
 		document:    "[{a: dog},{a: cat, b: banana},{a: cat, b: apple}]",
@@ -104,6 +114,16 @@ var sortByOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[null, false, true, 3, 6, 8, cat]\n",
 		},
 	},
+	{
+		description: "Sort, nulls come first",
+		skipDoc:     true,
+		document:    "[8,null]",
+		expression:  `sort[]`,
+		expected: []string{
+			"D0, P[1], (!!null)::null\n",
+			"D0, P[0], (!!int)::8\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "false before true",
