@@ -35,6 +35,15 @@ steps:
 `
 
 var traversePathOperatorScenarios = []expressionScenario{
+	{
+		skipDoc:     true,
+		description: "access merge anchors",
+		document:    "foo: &foo {x: y}\nbar:\n  <<: *foo\n",
+		expression:  `.bar["<<"] | alias`,
+		expected: []string{
+			"D0, P[bar <<], (!!str)::foo\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "dynamically set parent and key",
